@@ -93,9 +93,9 @@ class Log(object):
             handler.level = level
 
     # pylint: disable=too-many-locals,too-many-arguments,too-many-statements
-    def __init__(self, name, level=None, global_level=True, logs_dir=None,  # noqa: C901
+    def __init__(self, name, level=None, global_level=True, logs_dir=None, log_session_filename=None,  # noqa: C901
                  max_log_files=None, file_message_format=None, screen_message_format=None, date_format_full=None,
-                 date_format=None, direct=True):
+                 date_format=None, use_colors=True, direct=True):
         if direct:
             raise ValueError("You should create Global Logger via Log.get_logger() method.")
 
@@ -107,12 +107,14 @@ class Log(object):
             level = Log.Levels.DEBUG
 
         self.name = name
+        self.use_colors = use_colors
         Log.LOGGER_FILE_MESSAGE_FORMAT = file_message_format or Log.LOGGER_FILE_MESSAGE_FORMAT
         Log.LOGGER_SCREEN_MESSAGE_FORMAT = screen_message_format or Log.LOGGER_SCREEN_MESSAGE_FORMAT
         Log.LOGGER_DATE_FORMAT_FULL = date_format_full or Log.LOGGER_DATE_FORMAT_FULL
         Log.LOGGER_DATE_FORMAT = date_format or Log.LOGGER_DATE_FORMAT
         Log.MAX_LOG_FILES = max_log_files or Log.MAX_LOG_FILES
         Log.logs_dir = Log.logs_dir or logs_dir  # or Log.logs_dir or Log.DEFAULT_LOGS_DIR
+        Log.log_session_filename = Log.log_session_filename or log_session_filename
 
         self.logger = logging.getLogger(self.name)
         self.logger.propagate = False  # this fixes a recursion if other modules also use logging
@@ -139,18 +141,19 @@ class Log(object):
                 Log.log_session_filename = "%s.log" % now.strftime('%Y-%m-%d_%H-%M-%S')
                 self._clean_logs_folder()
 
-        # noinspection PyTypeChecker
-        color_formatter = ColoredFormatter(fmt=Log.LOGGER_SCREEN_MESSAGE_FORMAT, datefmt=Log.LOGGER_DATE_FORMAT,
-                                           reset=True, log_colors=default_log_colors)
-
         self._stdout_handler = logging.StreamHandler(sys.stdout)
         self._stdout_handler.addFilter(InfoFilter())
         self.logger.addHandler(self._stdout_handler)
-        self._stdout_handler.setFormatter(color_formatter)
 
         self._stderr_handler = logging.StreamHandler(sys.stderr)
         self.logger.addHandler(self._stderr_handler)
-        self._stderr_handler.setFormatter(color_formatter)
+
+        if self.use_colors:
+            # noinspection PyTypeChecker
+            color_formatter = ColoredFormatter(fmt=Log.LOGGER_SCREEN_MESSAGE_FORMAT, datefmt=Log.LOGGER_DATE_FORMAT,
+                                               reset=True, log_colors=default_log_colors)
+            self._stdout_handler.setFormatter(color_formatter)
+            self._stderr_handler.setFormatter(color_formatter)
 
         self._filehandler = None  # type: Union[logging.FileHandler, None]
         if Log.logs_dir:
@@ -208,8 +211,9 @@ class Log(object):
 
     # pylint: disable=too-many-arguments
     @classmethod
-    def get_logger(cls, name=None, level=None, global_level=True, logs_dir=None, max_log_files=None,
-                   file_message_format=None, screen_message_format=None, date_format_full=None, date_format=None):
+    def get_logger(cls, name=None, level=None, global_level=True, logs_dir=None, log_session_filename=None,
+                   max_log_files=None, file_message_format=None, screen_message_format=None, date_format_full=None,
+                   date_format=None, use_colors=True):
         """
         Main instantiating method for the class. Use it to instantiate global logger.
 
@@ -222,6 +226,8 @@ class Log(object):
         :type global_level: bool
         :param logs_dir: Path where the .log files would be created, if provided.
         :type logs_dir: Path or str or None
+        :param log_session_filename: Log output filename.
+        :type log_session_filename: str or None
         :param max_log_files: Maximum .log files to store.
         :type max_log_files: int
         :param screen_message_format: Screen Logging message format.
@@ -232,12 +238,15 @@ class Log(object):
         :type date_format_full: str
         :param date_format: Logging on-screen date format.
         :type date_format: str
+        :param use_colors: Use colored Stdout and Stderr output
+        :type use_colors: bool
         :return: :class:`Log` instance to work with.
         :rtype: :class:`Log`
         """
         name = name or get_prev_function_name()
         output = Log.loggers.get(name) or cls(name, level=level, global_level=global_level, logs_dir=logs_dir,
-                                              max_log_files=max_log_files, file_message_format=file_message_format,
+                                              log_session_filename=log_session_filename, max_log_files=max_log_files,
+                                              file_message_format=file_message_format, use_colors=use_colors,
                                               screen_message_format=screen_message_format,
                                               date_format_full=date_format_full, date_format=date_format, direct=False)
         Log.loggers[name] = output
@@ -286,6 +295,9 @@ class Log(object):
 
     @property
     def _log_files(self):
+        if not Log.logs_dir:
+            return []
+
         output = sorted(list(Log.logs_dir.glob('*.log')), key=lambda f: f.stat().st_ctime,
                         reverse=True)
         return output
@@ -325,7 +337,7 @@ class Log(object):
         default_end = '\n'
         end = kwargs.get(str('end'), None)
         color = kwargs.get(str('color'))
-        clear = kwargs.get(str('clear'), True)
+        clear = kwargs.get(str('clear'), self.use_colors)
         print_end = kwargs.get(str('end'), default_end)
         for msg in message:
             timestamp = '' if end == '' else '%s ' % time.strftime(str("%H:%M:%S"))
@@ -348,6 +360,7 @@ class Log(object):
             _colored_msg = _cleared_message
             if color:
                 if not isinstance(color, AnsiFore):
+                    # noinspection PyUnresolvedReferences
                     color = getattr(Fore, color.upper(), Fore.GREEN)
                 _colored_msg = '%s%s%s' % (color, _cleared_message, Fore.RESET)
 
